#
# spec file for package libpng16
#
# Copyright (c) 2022-2023 ZhuningOS
#


%define debug_build 0
%define asan_build  0

%define major   1
%define minor   6
%define micro   34
%define branch  %{major}%{minor}
%define libname libpng%{branch}-%{branch}
%define debug_package_requires %{libname} = %{version}-%{release}
Name:           libpng16
Version:        %{major}.%{minor}.%{micro}
Release:        3.9.1
Summary:        Library for the Portable Network Graphics Format (PNG)
License:        Zlib
Group:          Development/Libraries/C and C++
Url:            http://www.libpng.org/pub/png/libpng.html
Source0:        ftp://ftp.simplesystems.org/pub/png/src/libpng16/libpng-%{version}.tar.xz
Source1:        ftp://ftp.simplesystems.org/pub/png/src/libpng16/libpng-%{version}.tar.xz.asc
Source2:        libpng16.keyring
Source3:        rpm-macros.libpng-tools
Source4:        baselibs.conf
Patch0:         libpng16-CVE-2018-13785.patch
# CVE-2019-7317 [bsc#1124211]
Patch1:         libpng16-CVE-2019-7317.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

%package -n %{libname}
Summary:        Library for the Portable Network Graphics Format (PNG)
Group:          System/Libraries

%package devel
Summary:        Development tools for applications which will use libpng
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel
Requires:       pkgconfig
Requires:       zlib-devel
Recommends:     libpng%{branch}-compat-devel
#

%package compat-devel
Summary:        Development tools for applications which will use libpng
Group:          Development/Libraries/C and C++
Requires:       libpng%{branch}-devel = %{version}
Conflicts:      libpng-devel
Provides:       libpng-devel = %{version}
Obsoletes:      libpng-devel < 1.2.44

%package tools
Summary:        Tools for Manipulating PNG Images
Group:          Productivity/Graphics/Other
Conflicts:      libpng-tools
Provides:       libpng-tools = %{version}

%description
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%description -n %{libname}
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%description devel
The libpng%{branch}-devel package includes the header files, libraries,
configuration files and development tools necessary for compiling and
linking programs which will manipulate PNG files using libpng%{branch}.

libpng is the official reference library for the Portable Network
Graphics (PNG) format.

%description compat-devel
The libpng%{branch}-compat-devel package contains unversioned symlinks
to the header files, libraries, configuration files and development
tools necessary for compiling and linking programs that don't care
about libpng version.

%description tools
Package consists of low level tools for manipulating and fixing particular
PNG files.

%prep
%setup -q -n libpng-%{version}
%patch0 -p1
%patch1 -p1

%build
# PNG_SAFE_LIMITS_SUPPORTED: http://www.openwall.com/lists/oss-security/2015/01/10/1
export CFLAGS="%{optflags} -O3 -DPNG_SAFE_LIMITS_SUPPORTED -DPNG_SKIP_SETJMP_CHECK $(getconf LFS_CFLAGS)"
export LDFLAGS="-Wl,-z,relro,-z,now"
%if %{debug_build}
export CFLAGS="$CFLAGS -O0"
%endif
%configure \
              --disable-static
%if %{asan_build}
sed -i -e 's/^\(CFLAGS.*\)$/\1 -fsanitize=address/' \
       -e 's/\(^LIBS =.*\)/\1 -lasan/' Makefile
%endif
make %{?_smp_mflags}

%check
make -j1 check

%install
%make_install
rm %{buildroot}/%{_libdir}/libpng*.la
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp -a %{SOURCE3} \
      %{buildroot}%{_sysconfdir}/rpm/macros.libpng-tools
%if %{debug_build} ||%{asan_build}
install -m755 .libs/pngcp %{buildroot}/%{_bindir}
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/libpng%{branch}.so.*

%files devel
%{_bindir}/libpng%{branch}-config
%{_includedir}/libpng%{branch}
%{_libdir}/libpng%{branch}.so
%{_libdir}/pkgconfig/libpng%{branch}.pc
%doc CHANGES README TODO ANNOUNCE LICENSE libpng-*.txt

%files compat-devel
%{_bindir}/libpng-config
%{_includedir}/*.h
%{_libdir}/libpng.so
%{_libdir}/pkgconfig/libpng.pc
%{_mandir}/man3/libpng.3%{ext_man}
%{_mandir}/man3/libpngpf.3%{ext_man}
%{_mandir}/man5/png.5%{ext_man}

%files tools
%{_bindir}/png-fix-itxt
%{_bindir}/pngfix
%{_sysconfdir}/rpm/macros.libpng-tools
%if %{debug_build} || %{asan_build}
%{_bindir}/pngcp
%endif

%changelog
